@@ -18,6 +18,7 @@ import zipfile
 import six
 import logging
 import uuid
+import warnings
 import posixpath as zip_path
 import os.path
 from collections import OrderedDict
@@ -35,7 +36,7 @@ from ebooklib.utils import parse_string, parse_html_string, guess_type, get_page
 
 
 # Version of EPUB library
-VERSION = (0, 17, 1)
+VERSION = (0, 18, 1)
 
 NAMESPACES = {'XML': 'http://www.w3.org/XML/1998/namespace',
               'EPUB': 'http://www.idpf.org/2007/ops',
@@ -49,7 +50,7 @@ NAMESPACES = {'XML': 'http://www.w3.org/XML/1998/namespace',
 
 CONTAINER_PATH = 'META-INF/container.xml'
 
-CONTAINER_XML = '''<?xml version='1.0' encoding='utf-8'?>
+CONTAINER_XML = '''<?xml version="1.0" encoding="utf-8"?>
 <container xmlns="urn:oasis:names:tc:opendocument:xmlns:container" version="1.0">
   <rootfiles>
     <rootfile media-type="application/oebps-package+xml" full-path="%(folder_name)s/content.opf"/>
@@ -303,6 +304,9 @@ class EpubHtml(EpubItem):
         >>> add_link(href='styles.css', rel='stylesheet', type='text/css')
         """
         self.links.append(kwgs)
+        if kwgs.get('type') == 'text/javascript':
+            if 'scripted' not in self.properties:
+                self.properties.append('scripted')
 
     def get_links(self):
         """
@@ -423,6 +427,7 @@ class EpubHtml(EpubItem):
         _body = etree.SubElement(tree_root, 'body')
         if self.direction:
             _body.set('dir', self.direction)
+            tree_root.set('dir', self.direction)
 
         body = html_tree.find('body')
         if body is not None:
@@ -491,8 +496,8 @@ class EpubNav(EpubHtml):
     Represents Navigation Document in the EPUB file.
     """
 
-    def __init__(self, uid='nav', file_name='nav.xhtml', media_type='application/xhtml+xml'):
-        super(EpubNav, self).__init__(uid=uid, file_name=file_name, media_type=media_type)
+    def __init__(self, uid='nav', file_name='nav.xhtml', media_type='application/xhtml+xml', title=''):
+        super(EpubNav, self).__init__(uid=uid, file_name=file_name, media_type=media_type, title=title)
 
     def is_chapter(self):
         """
@@ -514,8 +519,8 @@ class EpubImage(EpubItem):
     Represents Image in the EPUB file.
     """
 
-    def __init__(self):
-        super(EpubImage, self).__init__()
+    def __init__(self, *args, **kwargs):
+        super(EpubImage, self).__init__(*args, **kwargs)
 
     def get_type(self):
         return ebooklib.ITEM_IMAGE
@@ -730,8 +735,8 @@ class EpubBook(object):
                 item.id = 'image_%d' % self._id_image
                 self._id_image += 1
             else:
-                item.id = 'static_%d' % self._id_image
-                self._id_image += 1
+                item.id = 'static_%d' % self._id_static
+                self._id_static += 1
 
         item.book = self
         self.items.append(item)
@@ -1119,7 +1124,7 @@ class EpubWriter(object):
 
         head = etree.SubElement(root, 'head')
         title = etree.SubElement(head, 'title')
-        title.text = self.book.title
+        title.text = item.title or self.book.title
 
         # for now this just handles css files and ignores others
         for _link in item.links:
@@ -1135,7 +1140,7 @@ class EpubWriter(object):
         })
 
         content_title = etree.SubElement(nav, 'h2')
-        content_title.text = self.book.title
+        content_title.text = item.title or self.book.title
 
         def _create_section(itm, items):
             ol = etree.SubElement(itm, 'ol')
@@ -1367,7 +1372,9 @@ class EpubWriter(object):
 
 
 class EpubReader(object):
-    DEFAULT_OPTIONS = {}
+    DEFAULT_OPTIONS = {
+        'ignore_ncx': False
+    }
 
     def __init__(self, epub_file_name, options=None):
         self.file_name = epub_file_name
@@ -1381,6 +1388,12 @@ class EpubReader(object):
         if options:
             self.options.update(options)
 
+        self._check_deprecated()
+
+    def _check_deprecated(self):
+        if not self.options.get('ignore_ncx'):
+            warnings.warn('In the future version we will turn default option ignore_ncx to True.')
+
     def process(self):
         # should cache this html parsing so we don't do it for every plugin
         for plg in self.options.get('plugins', []):
@@ -1495,7 +1508,7 @@ class EpubReader(object):
                 ei = EpubNcx(uid=r.get('id'), file_name=unquote(r.get('href')))
 
                 ei.content = self.read_file(zip_path.join(self.opf_dir, ei.file_name))
-            if media_type == 'application/smil+xml':
+            elif media_type == 'application/smil+xml':
                 ei = EpubSMIL(uid=r.get('id'), file_name=unquote(r.get('href')))
 
                 ei.content = self.read_file(zip_path.join(self.opf_dir, ei.file_name))
@@ -1639,13 +1652,15 @@ class EpubReader(object):
         self.book.set_direction(spine.get('page-progression-direction', None))
 
         # should read ncx or nav file
+        nav_item = next((item for item in self.book.items if isinstance(item, EpubNav)), None)
         if toc:
-            try:
-                ncxFile = self.read_file(zip_path.join(self.opf_dir, self.book.get_item_with_id(toc).get_name()))
-            except KeyError:
-                raise EpubException(-1, 'Can not find ncx file.')
+            if not self.options.get('ignore_ncx') or not nav_item:
+                try:
+                    ncxFile = self.read_file(zip_path.join(self.opf_dir, self.book.get_item_with_id(toc).get_name()))
+                except KeyError:
+                    raise EpubException(-1, 'Can not find ncx file.')
 
-            self._parse_ncx(ncxFile)
+                self._parse_ncx(ncxFile)
 
     def _load_guide(self):
         guide = self.container.find('{%s}%s' % (NAMESPACES['OPF'], 'guide'))
@@ -1669,7 +1684,7 @@ class EpubReader(object):
         #
         nav_item = next((item for item in self.book.items if isinstance(item, EpubNav)), None)
         if nav_item:
-            if not self.book.toc:
+            if self.options.get('ignore_ncx') or not self.book.toc:
                 self._parse_nav(
                     nav_item.content,
                     zip_path.dirname(nav_item.file_name),
@@ -1682,12 +1697,25 @@ class EpubReader(object):
             )
 
     def _load(self):
-        try:
-            self.zf = zipfile.ZipFile(self.file_name, 'r', compression=zipfile.ZIP_DEFLATED, allowZip64=True)
-        except zipfile.BadZipfile as bz:
-            raise EpubException(0, 'Bad Zip file')
-        except zipfile.LargeZipFile as bz:
-            raise EpubException(1, 'Large Zip file')
+        if os.path.isdir(self.file_name):
+            file_name = self.file_name
+
+            class Directory:
+                def read(self, subname):
+                    with open(os.path.join(file_name, subname), 'rb') as fp:
+                        return fp.read()
+
+                def close(self):
+                    pass
+
+            self.zf = Directory()
+        else:
+            try:
+                self.zf = zipfile.ZipFile(self.file_name, 'r', compression=zipfile.ZIP_DEFLATED, allowZip64=True)
+            except zipfile.BadZipfile as bz:
+                raise EpubException(0, 'Bad Zip file')
+            except zipfile.LargeZipFile as bz:
+                raise EpubException(1, 'Large Zip file')
 
         # 1st check metadata
         self._load_container()
@@ -1696,6 +1724,7 @@ class EpubReader(object):
         self.zf.close()
 
 
+
 # WRITE
 
 def write_epub(name, book, options=None):
